/*
 *    GS2MacroResolver.java
 *    Copyright (C) 2005 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.util;

import java.util.ArrayList;
import org.greenstone.gdbm.GDBMWrapper;
import org.greenstone.gdbm.DBInfo;

public class GS2MacroResolver 
    extends MacroResolver 
{

    protected GDBMWrapper gdbm_src = null;
    
    // need to make it not add macros if they are already present
    public GS2MacroResolver(GDBMWrapper gdbm) {
	gdbm_src = gdbm;
    }

    
     public String resolve(String text, String lang, String scope, 
			  String doc_oid) {
	//System.err.println("resolving macros for "+text);
	if (scope.equals(SCOPE_TEXT) && text_macros.size()==0) return text;
	if (scope.equals(SCOPE_META) && metadata_macros.size() ==0) return text;

	DBInfo node_info = null;
	DBInfo root_info = null;
	boolean new_lang = false;
	if (this.lang == null || !this.lang.equals(lang) ) {
	    new_lang = true;
	    this.lang = lang;
	} 

	ArrayList macros;
	if (scope.equals(SCOPE_TEXT)) {
	    macros = text_macros;
	} else {
	    macros = metadata_macros;
	}
	
	for (int i=0; i<macros.size(); i++) {
	    Macro m = (Macro)macros.get(i);
	    switch (m.type) {
	    case TYPE_DICT:
		if (m.text==null || new_lang) {
		    Dictionary dict = new Dictionary(m.bundle, lang);
		    m.text = dict.get(m.key, null);
		}
		// now drop through to text case
	    case TYPE_TEXT:
		text = text.replaceAll(m.macro, m.text);
		break;
	    case TYPE_META:
		if (text.indexOf(m.macro) != -1) {
		    if (node_info == null) {
			node_info = gdbm_src.getInfo(doc_oid);
			if (node_info == null) {
			    break;
			}
		    }
		    
		    String value = node_info.getInfo(m.text);
		    if (value != null) {
			text = text.replaceAll(m.macro, value);
		    } else {
			// try the root node
			if (root_info == null && !OID.isTop(doc_oid)) {
			    root_info = gdbm_src.getInfo(OID.getTop(doc_oid));
			}
			if (root_info == null) break;
			value = root_info.getInfo(m.text);
			if (value != null) {
			    text = text.replaceAll(m.macro, value);
			}
		    }
		}
		
		break;
	    } // switch
	   
	}
	
	return text;
	
    }

}
